<?php

namespace Pure\Career\Http\Controllers;

use App\Http\Controllers\Controller as BaseController;
use Pure\Career\Http\Requests\CareerCategoryRequest;
use Pure\Career\Models\CareerCategory;

/**
 * Admin web controller class.
 */
class CareerCategoryWorkflowController extends BaseController
{

    /**
     * Workflow controller function for career_category.
     *
     * @param Model   $career_category
     * @param step    next step for the workflow.
     *
     * @return Response
     */

    public function putWorkflow(CareerCategoryRequest $request, CareerCategory $career_category, $step)
    {

        try {

            $career_category->updateWorkflow($step);

            return response()->json([
                'message'  => trans('messages.success.changed', ['Module' => trans('career::career_category.name'), 'status' => trans("app.{$step}")]),
                'code'     => 204,
                'redirect' => trans_url('/admin/career_category/career_category/' . $career_category->getRouteKey()),
            ], 201);

        } catch (Exception $e) {

            return response()->json([
                'message'  => $e->getMessage(),
                'code'     => 400,
                'redirect' => trans_url('/admin/career_category/career_category/' . $career_category->getRouteKey()),
            ], 400);

        }

    }

    /**
     * Workflow controller function for career_category.
     *
     * @param Model   $career_category
     * @param step    next step for the workflow.
     * @param user    encrypted user id.
     *
     * @return Response
     */

    public function getWorkflow(CareerCategory $career_category, $step, $user)
    {
        try {
            $user_id = decrypt($user);

            Auth::onceUsingId($user_id);

            $career_category->updateWorkflow($step);

            $data = [
                'message' => trans('messages.success.changed', ['Module' => trans('career::career_category.name'), 'status' => trans("app.{$step}")]),
                'status'  => 'success',
                'step'    => trans("app.{$step}"),
            ];

            return $this->theme->layout('blank')->of('career::admin.career_category.message', $data)->render();

        } catch (ValidationException $e) {

            $data = [
                'message' => '<b>' . $e->getMessage() . '</b> <br /><br />' . implode('<br />', $e->validator->errors()->all()),
                'status'  => 'error',
                'step'    => trans("app.{$step}"),
            ];

            return $this->theme->layout('blank')->of('career::admin.career_category.message', $data)->render();

        } catch (Exception $e) {

            $data = [
                'message' => '<b>' . $e->getMessage() . '</b>',
                'status'  => 'error',
                'step'    => trans("app.{$step}"),
            ];

            return $this->theme->layout('blank')->of('career::admin.career_category.message', $data)->render();

        }

    }
}
