<?php

namespace Pure\Career\Policies;

use Litepie\User\Contracts\UserPolicy;
use Pure\Career\Models\CareerMeta;

class CareerMetaPolicy
{

    /**
     * Determine if the given user can view the career_meta.
     *
     * @param UserPolicy $user
     * @param CareerMeta $career_meta
     *
     * @return bool
     */
    public function view(UserPolicy $user, CareerMeta $career_meta)
    {
        if ($user->canDo('career.career_meta.view') && $user->isAdmin()) {
            return true;
        }

        return $career_meta->user_id == user_id() && $career_meta->user_type == user_type();
    }

    /**
     * Determine if the given user can create a career_meta.
     *
     * @param UserPolicy $user
     * @param CareerMeta $career_meta
     *
     * @return bool
     */
    public function create(UserPolicy $user)
    {
        return  $user->canDo('career.career_meta.create');
    }

    /**
     * Determine if the given user can update the given career_meta.
     *
     * @param UserPolicy $user
     * @param CareerMeta $career_meta
     *
     * @return bool
     */
    public function update(UserPolicy $user, CareerMeta $career_meta)
    {
        if ($user->canDo('career.career_meta.edit') && $user->isAdmin()) {
            return true;
        }

        return $career_meta->user_id == user_id() && $career_meta->user_type == user_type();
    }

    /**
     * Determine if the given user can delete the given career_meta.
     *
     * @param UserPolicy $user
     * @param CareerMeta $career_meta
     *
     * @return bool
     */
    public function destroy(UserPolicy $user, CareerMeta $career_meta)
    {
        return $career_meta->user_id == user_id() && $career_meta->user_type == user_type();
    }

    /**
     * Determine if the given user can verify the given career_meta.
     *
     * @param UserPolicy $user
     * @param CareerMeta $career_meta
     *
     * @return bool
     */
    public function verify(UserPolicy $user, CareerMeta $career_meta)
    {
        if ($user->canDo('career.career_meta.verify')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the given user can approve the given career_meta.
     *
     * @param UserPolicy $user
     * @param CareerMeta $career_meta
     *
     * @return bool
     */
    public function approve(UserPolicy $user, CareerMeta $career_meta)
    {
        if ($user->canDo('career.career_meta.approve')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the user can perform a given action ve.
     *
     * @param [type] $user    [description]
     * @param [type] $ability [description]
     *
     * @return [type] [description]
     */
    public function before($user, $ability)
    {
        if ($user->isSuperuser()) {
            return true;
        }
    }
}
