<?php

namespace Pure\Career\Providers;

use Illuminate\Support\ServiceProvider;

class CareerServiceProvider extends ServiceProvider
{
    /**
     * Indicates if loading of the provider is deferred.
     *
     * @var bool
     */
    protected $defer = false;

    /**
     * Bootstrap the application events.
     *
     * @return void
     */
    public function boot()
    {
        // Load view
        $this->loadViewsFrom(__DIR__ . '/../../resources/views', 'career');

        // Load translation
        $this->loadTranslationsFrom(__DIR__ . '/../../resources/lang', 'career');

        // Load migrations
        $this->loadMigrationsFrom(__DIR__ . '/../../database/migrations');

        // Call pblish redources function
        $this->publishResources();

    }

    /**
     * Register the service provider.
     *
     * @return void
     */
    public function register()
    {
        $this->mergeConfig();
        $this->registerCareer();
        $this->registerFacade();
        $this->registerBindings();
        //$this->registerCommands();
    }


    /**
     * Register the application bindings.
     *
     * @return void
     */
    protected function registerCareer()
    {
        $this->app->bind('career', function($app) {
            return new Career($app);
        });
    }

    /**
     * Register the vault facade without the user having to add it to the app.php file.
     *
     * @return void
     */
    public function registerFacade() {
        $this->app->booting(function()
        {
            $loader = \Illuminate\Foundation\AliasLoader::getInstance();
            $loader->alias('Career', 'Lavalite\Career\Facades\Career');
        });
    }

    /**
     * Register bindings for the provider.
     *
     * @return void
     */
    public function registerBindings() {
        // Bind facade
        $this->app->bind('pure.career', function ($app) {
            return $this->app->make('Pure\Career\Career');
        });

        // Bind CareerJob to repository
        $this->app->bind(
            'Pure\Career\Interfaces\CareerJobRepositoryInterface',
            \Pure\Career\Repositories\Eloquent\CareerJobRepository::class
        );        // Bind CareerCategory to repository
        $this->app->bind(
            'Pure\Career\Interfaces\CareerCategoryRepositoryInterface',
            \Pure\Career\Repositories\Eloquent\CareerCategoryRepository::class
        );        // Bind CareerApplication to repository
        $this->app->bind(
            'Pure\Career\Interfaces\CareerApplicationRepositoryInterface',
            \Pure\Career\Repositories\Eloquent\CareerApplicationRepository::class
        );        // Bind CareerMeta to repository
        $this->app->bind(
            'Pure\Career\Interfaces\CareerMetaRepositoryInterface',
            \Pure\Career\Repositories\Eloquent\CareerMetaRepository::class
        );

        $this->app->register(\Pure\Career\Providers\AuthServiceProvider::class);
                $this->app->register(\Pure\Career\Providers\EventServiceProvider::class);
        
        $this->app->register(\Pure\Career\Providers\RouteServiceProvider::class);
                $this->app->register(\Pure\Career\Providers\WorkflowServiceProvider::class);
            }

    /**
     * Merges user's and career's configs.
     *
     * @return void
     */
    protected function mergeConfig()
    {
        $this->mergeConfigFrom(
            __DIR__ . '/../../config/career.php', 'career'
        );
    }

    /**
     * Register scaffolding command
     */
    protected function registerCommands()
    {
        if ($this->app->runningInConsole()) {
            $this->commands([
                Commands\MakeCareer::class,
            ]);
        }
    }
    /**
     * Get the services provided by the provider.
     *
     * @return array
     */
    public function provides()
    {
        return ['pure.career'];
    }

    /**
     * Publish resources.
     *
     * @return void
     */
    private function publishResources()
    {
        // Publish configuration file
        $this->publishes([__DIR__ . '/../../config/config.php' => config_path('pure/career.php')], 'config');

        // Publish admin view
        $this->publishes([__DIR__ . '/../../resources/views' => base_path('resources/views/vendor/career')], 'view');

        // Publish language files
        $this->publishes([__DIR__ . '/../../resources/lang' => base_path('resources/lang/vendor/career')], 'lang');

        // Publish public files and assets.
        $this->publishes([__DIR__ . '/public/' => public_path('/')], 'public');
    }
}
